@@ -70,7 +70,6 @@
 #include "executablesearchpaths.h"
 #include "zuluPolkit.h"
 #include "luks_slot_status.h"
-#include "cryptsetup_library_path.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -378,8 +377,8 @@ static bool _enable_polkit_support( const QString& m )
 	return !s ;
 }
 
-void utility::startHelperExecutable( QObject * obj,const QString& arg,const QString& exe,
-				     const char * slot,const char * slot1 )
+void utility::startHelper( QObject * obj,const QString& arg,const QString& exe,
+				     utility::startHelperStatus status )
 {
 	if( _enable_polkit_support( exe ) ){
 
@@ -391,19 +390,19 @@ void utility::startHelperExecutable( QObject * obj,const QString& arg,const QStr
 
 				_run_through_polkit = e.success() ;
 
-				QMetaObject::invokeMethod( obj,
-							   slot,
-							   Q_ARG( bool,e.success() ),
-							   Q_ARG( QString,arg ) ) ;
+				utility::invokeMethod( obj,[ s = e.success(),arg,status ](){
+
+					status.success( s,arg ) ;
+				} ) ;
 			} ) ;
 		}else{
 			DialogMsg().ShowUIOK( QObject::tr( "ERROR" ),
 					      QObject::tr( "Failed to locate pkexec executable" ) ) ;
 
-			QMetaObject::invokeMethod( obj,slot1 ) ;
+			utility::invokeMethod( obj,[ = ]{ status.error() ; } ) ;
 		}
 	}else{
-		QMetaObject::invokeMethod( obj,slot,Q_ARG( bool,true ),Q_ARG( QString,arg ) ) ;
+		utility::invokeMethod( obj,[ = ](){ status.success( true,arg ) ; } ) ;
 	}
 }
 
@@ -652,11 +651,6 @@ int utility::startApplication( const char * appName,std::function<int()> start )
 	}
 }
 
-void utility::startApplication( QObject * s,const char * e )
-{
-	QMetaObject::invokeMethod( s,e,Qt::QueuedConnection ) ;
-}
-
 void utility::keySend( const QString& path,const QByteArray& key )
 {
 	::Task::exec( [ path,key ](){
@@ -688,51 +682,31 @@ void utility::keySend( const QString& keyPath,const QString& key )
 	utility::keySend( keyPath,key.toLatin1() ) ;
 }
 
-void utility::createPlugInMenu( QMenu * menu,const QString& a,const QString& b,const QString& c,bool addPlugIns )
+void utility::addPluginsToMenu( QMenu& menu )
 {
-	QStringList l ;
 	QStringList e ;
 
-	l.append( a ) ;
+	QDir dir( ZULUCRYPTpluginPath ) ;
 
-	if( LXQt::Wallet::backEndIsSupported( LXQt::Wallet::BackEnd::libsecret ) ){
+	if( dir.exists() ){
 
-		l.append( b ) ;
-	}
-	if( LXQt::Wallet::backEndIsSupported( LXQt::Wallet::BackEnd::kwallet ) ){
+		e = dir.entryList() ;
 
-		l.append( c ) ;
+		e.removeOne( "zuluCrypt-testKey" ) ;
+		e.removeOne( "." ) ;
+		e.removeOne( ".." ) ;
+		e.removeOne( "keyring" ) ;
+		e.removeOne( "kwallet" ) ;
 	}
 
-	if( addPlugIns ){
-
-		QDir dir( ZULUCRYPTpluginPath ) ;
-
-		if( dir.exists() ){
-
-			e = dir.entryList() ;
-
-			e.removeOne( "zuluCrypt-testKey" ) ;
-			e.removeOne( "." ) ;
-			e.removeOne( ".." ) ;
-			e.removeOne( "keyring" ) ;
-			e.removeOne( "kwallet" ) ;
-		}
-
-		//e.append( "network" ) ;
-	}
-
-	menu->clear() ;
-
-	auto _add_actions = [ menu ]( const QStringList& r ){
+	auto _add_actions = [ &menu ]( const QStringList& r ){
 
 		for( const auto& it : r ){
 
-			menu->addAction( it ) ;
+			menu.addAction( it )->setObjectName( it ) ;
 		}
 	} ;
 
-	_add_actions( l ) ;
 	_add_actions( e ) ;
 }
 
@@ -2082,7 +2056,12 @@ public:
 
 			e = new QTranslator() ;
 
-			e->load( r.constData(),utility::localizationLanguagePath( app ) ) ;
+			auto mm = e->load( r.constData(),utility::localizationLanguagePath( app ) ) ;
+
+			if( !mm ){
+
+				//??
+			}
 
 			*( f + s ) = e ;
 
@@ -2299,6 +2278,31 @@ bool utility::autoOpenFolderOnMount( const QString& app )
 	}
 }
 
+QString utility::defaultPlugin()
+{
+	if( !_settings->contains( "DefaultPlugin" ) ){
+
+		QMenu m ;
+		utility::addPluginsToMenu( m ) ;
+		auto s = m.actions() ;
+
+		if( s.size() ){
+
+			_settings->setValue( "DefaultPlugin",s.at( 0 )->text() ) ;
+		}
+	}
+
+	return _settings->value( "DefaultPlugin" ).toString() ;
+}
+
+void utility::setDefaultPlugin( const QString& e )
+{
+	if( !e.isEmpty() ){
+
+		_settings->setValue( "DefaultPlugin",e ) ;
+	}
+}
+
 QString utility::powerOffCommand()
 {
 	if( _settings->contains( "PowerOffCommand" ) ){
@@ -2408,6 +2412,16 @@ QStringList utility::plainDmCryptOptions()
 	}
 }
 
+QString utility::KWalletDefaultName()
+{
+	if( !_settings->contains( "KWalletDefaultName" ) ){
+
+		_settings->setValue( "KWalletDefaultName","default" ) ;
+	}
+
+	return _settings->value( "KWalletDefaultName" ).toString() ;
+}
+
 QStringList utility::supportedFileSystems()
 {
 	if( _settings->contains( "SupportedFileSystems" ) ){
@@ -2484,8 +2498,10 @@ void utility::setHDPI( const QString& e )
 
 #if QT_VERSION >= 0x050600
 
-	QApplication::setAttribute( Qt::AA_EnableHighDpiScaling ) ;
+	#if QT_VERSION < QT_VERSION_CHECK( 6,0,0 )
 
+		QApplication::setAttribute( Qt::AA_EnableHighDpiScaling ) ;
+	#endif
 	if( !_settings->contains( "ScaleFactor" ) ){
 
 		_settings->setValue( "ScaleFactor","1" ) ;
@@ -3027,20 +3043,20 @@ void utility::progress::update_progress( quint64 size,quint64 offset )
 
 		m_progress = i ;
 
-		double currentTime = m_time.currentMSecsSinceEpoch() ;
+		double currentTime = static_cast< double >( m_time.currentMSecsSinceEpoch() ) ;
 
 		double time_diff = ( currentTime - m_previousTime ) / 1000 ;
-		double offset_diff = offset - m_offset_last ;
+		double offset_diff = static_cast< double >( offset - m_offset_last ) ;
 
 		m_total_time = m_total_time + time_diff ;
 
 		QString current_speed = this->speed( offset_diff,time_diff ) ;
 
-		QString average_speed = this->speed( offset,m_total_time ) ;
+		QString average_speed = this->speed( static_cast< double >( offset ),m_total_time ) ;
 
-		double avg_speed = offset / m_total_time ;
+		double avg_speed = static_cast< double >( offset ) / m_total_time ;
 
-		double remaining_data = size - offset ;
+		double remaining_data = static_cast< double >( size - offset ) ;
 
 		QString eta = this->time( remaining_data / avg_speed ) ;
 
@@ -3245,3 +3261,20 @@ QString utility::fileSystemOptions( const QString& path )
 
 	return m ;
 }
+
+QString utility::pathToUUID( const QString& path )
+{
+	if( path.startsWith( "UUID=" ) ){
+
+		return path ;
+	}else{
+		auto z = utility::getUUIDFromPath( path ).await() ;
+
+		if( z.isEmpty() ){
+
+			return utility::getVolumeID( path ) ;
+		}else{
+			return z ;
+		}
+	}
+}
